@@ -1,10 +1,10 @@
 from .bch import BCH
 from .bsty import BSTY
 from .btc import BTC
-from .gzro import GZRO
+from .eth import ETH
 from .ltc import LTC
 from .xrg import XRG
 
-COINS = {"BTC": BTC, "BCH": BCH, "LTC": LTC, "GZRO": GZRO, "BSTY": BSTY, "XRG": XRG}
+COINS = {"BTC": BTC, "BCH": BCH, "ETH": ETH, "LTC": LTC, "BSTY": BSTY, "XRG": XRG}
 
 __all__ = list(COINS.keys()) + ["COINS"]
