@@ -1,19 +1,29 @@
 import asyncio
-from typing import Any, Callable, Optional
+from typing import Any, Callable, Dict, Optional, Union
 from urllib.parse import urljoin
 
 import aiohttp
-from jsonrpcclient.clients.aiohttp_client import AiohttpClient as RPC
-from jsonrpcclient.exceptions import ReceivedErrorResponseError
-from jsonrpcclient.requests import Request
+from jsonrpcclient import Ok, parse_json, request
+from universalasync import async_to_sync_wraps, get_event_loop
 
 from ..errors import ConnectionFailedError, UnknownError, generate_exception
 from ..utils import json_encode
 
 
-class RPCProxy:
-    session: aiohttp.ClientSession
+def create_request(method: str, *args: Any, **kwargs: Any) -> dict:
+    params: Union[list, dict] = []
+    if args and kwargs:
+        # It actually violates json-rpc 2.0 spec but is pretty convenient for passing both positional and named arguments
+        params = list(args)
+        params.append(kwargs)
+    elif args:
+        params = list(args)
+    elif kwargs:
+        params = kwargs
+    return request(method, params)
 
+
+class RPCProxy:
     def __init__(
         self,
         url: str,
@@ -32,15 +42,20 @@ class RPCProxy:
         self.verify = verify
         self._connector_class = aiohttp.TCPConnector
         self._connector_init = dict(ssl=self.verify)
-        self._loop = asyncio.get_event_loop()
-        self._loop.set_exception_handler(lambda loop, context: None)
         self._spec = {"exceptions": {"-32600": {"exc_name": "UnauthorizedError", "docstring": "Unauthorized"}}}
         self._spec_valid = False
-        if session:
-            self.sesson = session
-        else:
-            self.create_session()
-        self.rpc = RPC(endpoint=self.url, session=self.session, timeout=5 * 60)
+        self._sessions: Dict[asyncio.AbstractEventLoop, aiohttp.ClientSession] = {}
+        if session is not None:
+            self._sessions[get_event_loop()] = session
+
+    @property
+    def session(self) -> aiohttp.ClientSession:
+        loop = get_event_loop()
+        session = self._sessions.get(loop)
+        if session is not None:
+            return session
+        self._sessions[loop] = self.create_session()
+        return self._sessions[loop]
 
     def init_proxy(self) -> None:
         if self.proxy:
@@ -58,11 +73,10 @@ class RPCProxy:
                 rdns=True,
             )
 
-    def create_session(self) -> None:
+    def create_session(self) -> aiohttp.ClientSession:
         self.init_proxy()
-        self.session = aiohttp.ClientSession(
+        return aiohttp.ClientSession(
             connector=self._connector_class(**self._connector_init),  # type: ignore
-            loop=self._loop,
             auth=aiohttp.BasicAuth(self.username, self.password),  # type: ignore
         )
 
@@ -99,35 +113,36 @@ class RPCProxy:
         return self._spec
 
     def __getattr__(self, method: str, *args: Any, **kwargs: Any) -> Callable:
-        from ..sync import async_to_sync_wraps
-
         @async_to_sync_wraps
         async def wrapper(*args: Any, **kwargs: Any) -> Any:
             try:
-                return (
-                    await self.rpc.send(
-                        json_encode(Request(method, xpub=self.xpub, *args, **kwargs)),
-                        validate_against_schema=False,
-                    )
-                ).data.result
-            except ReceivedErrorResponseError as e:
-                message = e.response.message
-                error_code = str(e.response.code)
-                exceptions = (await self.spec)["exceptions"]
-                if error_code in exceptions:
-                    exc = exceptions[error_code]
-                    raise generate_exception(exc["exc_name"])(exc["docstring"]) from e
-                raise UnknownError(f"Unknown error from server: {message}") from e
+                async with self.session.post(
+                    self.url, data=json_encode(create_request(method, xpub=self.xpub, *args, **kwargs)), timeout=5 * 60
+                ) as response:
+                    parsed = parse_json(await response.text())
+                    if isinstance(parsed, Ok):
+                        return parsed.result
+                    else:
+                        message = parsed.message
+                        error_code = str(parsed.code)
+                        exceptions = (await self.spec)["exceptions"]
+                        if error_code in exceptions:
+                            exc = exceptions[error_code]
+                            raise generate_exception(exc["exc_name"])(exc["docstring"])
+                        raise UnknownError(f"Unknown error from server: {message}")
             except aiohttp.ClientConnectionError as e:
                 raise ConnectionFailedError() from e
 
         return wrapper
 
     async def _close(self) -> None:
-        await self.session.close()
+        for session in self._sessions.values():
+            if session is not None:
+                await session.close()
 
     def __del__(self) -> None:
-        if self._loop.is_running():
-            self._loop.create_task(self._close())
+        loop = get_event_loop()
+        if loop.is_running():
+            loop.create_task(self._close())
         else:
-            self.session._connector._closed = True  # type: ignore
+            loop.run_until_complete(self._close())
